@@ -11,7 +11,7 @@ from differential.plugins.base import PARSER, REGISTERED_PLUGINS
 def main():
     args = PARSER.parse_args()
     logger.info("Differential 差速器 {}".format(version))
-    config = merge_config(args)
+    config = merge_config(args, args.section)
 
     if 'log' in config:
         log = config.pop('log')
@@ -23,11 +23,11 @@ def main():
             logger.trace(config)
             REGISTERED_PLUGINS[plugin](**config).upload()
         except TypeError as e:
-            m = re.search(r'missing \d+ required positional arguments: (.*?)$', str(e))
+            m = re.search(r'missing \d+ required positional argument[s]{0,1}: (.*?)$', str(e))
             if m:
                 logger.error("缺少插件必需的参数，请检查输入的参数: {}".format(m.groups()[0]))
-            else:
-                logger.error(e)
+                return
+            raise e
     else:
         PARSER.print_help()
 
