@@ -5,7 +5,10 @@ from typing import Optional
 import requests
 from loguru import logger
 
-def byr_upload(img: Path, authorization: str, url: Optional[str] = None) -> Optional[str]:
+from differential.utils.image import ImageUploaded
+
+
+def byr_upload(img: Path, authorization: str, url: Optional[str] = None) -> Optional[ImageUploaded]:
     headers = {'authorization': f'{authorization if authorization.startswith("Basic") else "Basic "+authorization}'}
     params = {'command': 'QuickUpload', 'type': 'Images', 'CKEditor': 'descr', 'CKEditorFuncNum': 2}
     files = {'upload': open(img, 'rb')}
@@ -24,4 +27,4 @@ def byr_upload(img: Path, authorization: str, url: Optional[str] = None) -> Opti
         logger.trace(req.content)
         logger.warning(f"图片直链获取失败")
         return None
-    return m.groups()[0]
+    return ImageUploaded(m.groups()[0])
