@@ -5,8 +5,9 @@ from typing import Optional
 import requests
 from loguru import logger
 
+from differential.utils.image import ImageUploaded
 
-def imgurl_upload(img: Path, url: str, api_key: str) -> Optional[str]:
+def imgurl_upload(img: Path, url: str, api_key: str) -> Optional[ImageUploaded]:
     data = {'token': api_key}
     files = {'file': open(img, 'rb')}
     req = requests.post(f'{url}/api/upload', data=data, files=files)
@@ -25,4 +26,4 @@ def imgurl_upload(img: Path, url: str, api_key: str) -> Optional[str]:
     if res.get('code') > 200:
         logger.warning(f"上传图片失败: [{res.get('code')}]{res.get('msg')}")
         return None
-    return res.get('url')
\ No newline at end of file
+    return ImageUploaded(res.get('url'))
\ No newline at end of file
