@@ -5,8 +5,9 @@ from typing import Optional
 import requests
 from loguru import logger
 
+from differential.utils.image import ImageUploaded
 
-def ptpimg_upload(img: Path, api_key: str) -> Optional[str]:
+def ptpimg_upload(img: Path, api_key: str) -> Optional[ImageUploaded]:
     data = {'api_key': api_key}
     files = {'file-upload[0]': open(img, 'rb')}
     req = requests.post('https://ptpimg.me/upload.php', data=data, files=files)
@@ -24,4 +25,4 @@ def ptpimg_upload(img: Path, api_key: str) -> Optional[str]:
     if len(res) < 1 or 'code' not in res[0] or 'ext' not in res[0]:
         logger.warning(f"图片直链获取失败")
         return None
-    return f"https://ptpimg.me/{res[0].get('code')}.{res[0].get('ext')}"
\ No newline at end of file
+    return ImageUploaded(f"https://ptpimg.me/{res[0].get('code')}.{res[0].get('ext')}")
\ No newline at end of file
