@@ -5,7 +5,10 @@ from typing import Optional
 import requests
 from loguru import logger
 
-def smms_upload(img: Path, api_key: str) -> Optional[str]:
+from differential.utils.image import ImageUploaded
+
+
+def smms_upload(img: Path, api_key: str) -> Optional[ImageUploaded]:
     data = {'Authorization': api_key}
     files = {'smfile': open(img, 'rb'), 'format': 'json'}
     req = requests.post('https://sm.ms/api/v2/upload', data=data, files=files)
@@ -29,4 +32,4 @@ def smms_upload(img: Path, api_key: str) -> Optional[str]:
     if 'data' not in res or 'url' not in res['data']:
         logger.warning(f"图片直链获取失败")
         return None
-    return res['data']['url']
\ No newline at end of file
+    return ImageUploaded(res['data']['url'])
\ No newline at end of file
